"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _webutil = require("./webutil.js");

var WebUtil = _interopRequireWildcard(_webutil);

var _keysym2qemuname = require("../core/input/syno/keysym2qemuname.js");

var _keysym2qemuname2 = _interopRequireDefault(_keysym2qemuname);

var _qemuname2keycode = require("../core/input/syno/qemuname2keycode.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var SYNO = {
    initPathSetting: function (scope, defVal) {
        // Check Query string followed by cookie
        var path = WebUtil.getConfigVar('path');
        var sharing_id = WebUtil.getConfigVar('sharing_id');

        if (path === null) {
            path = WebUtil.readSetting('path', defVal);
        }

        if (sharing_id !== null) {
            path += "?sharing_id=" + sharing_id;
        }

        scope.updateSetting('path', path);
        return path;
    },

    genModifierAndSendkey: function (sender, keysym, code, down, keyDownList) {
        if (!_keysym2qemuname2.default || !_qemuname2keycode.qemuName2KeyCode || !_qemuname2keycode.allKeyboardLayout) {
            return -1;
        }
        keyDownList = keyDownList ? keyDownList : {};
        var kb_layout = WebUtil.getQueryVar("kb_layout", "en-us");
        var keysym_name = _keysym2qemuname2.default[keysym];
        var keycode_arr = (0, _qemuname2keycode.qemuName2KeyCode)(kb_layout, keysym_name, keyDownList);
        if (!keycode_arr || 0 >= keycode_arr.length) {
            return -1;
        }
        // map modifier keycode to keysym
        var modifiers = {};
        for (var i = 1; i < keycode_arr.length; i++) {
            // Here we translate qemu_keycode name to xt_keycode name.
            // Ex: shift -> ShiftLeft
            switch (keycode_arr[i]) {
                case "shift":
                    modifiers["ShiftLeft"] = {
                        "keysym": 0xffe1,
                        "also_check": "ShiftRight"
                    };
                    break;
                case "altgr":
                    // altgr = alt + ctrl
                    modifiers["AltRight"] = {
                        "keysym": 0xffea,
                        "also_check": "AltLeft"
                    };
                case "ctrl":
                    modifiers["ControlLeft"] = {
                        "keysym": 0xffe3,
                        "also_check": "ControlRight"
                    };
                    break;
                case "numlock":
                    // We should make sure NumLock is on when seeing this key, but we don't know actual numlock state inside guest.
                    // Therefore, we just do nothig here.
                    break;
                default:
                    break;
            }
        }
        if ("boolean" !== typeof down || true === down) {
            for (var keycode in modifiers) {
                if (modifiers.hasOwnProperty(keycode) && !(keycode in keyDownList) && !(modifiers[keycode].also_check in keyDownList)) {
                    sender(modifiers[keycode].keysym, keycode, true);
                }
            }
        }
        sender(keysym, keycode_arr[0], down);
        if ("boolean" !== typeof down || false === down) {
            for (var keycode in modifiers) {
                if (modifiers.hasOwnProperty(keycode) && !(keycode in keyDownList) && !(modifiers[keycode].also_check in keyDownList)) {
                    sender(modifiers[keycode].keysym, keycode, false);
                }
            }
        }
        return 0;
    }
}; /* Copyright (c) 2017 Synology Inc. All rights reserved. */
exports.default = SYNO;